==> vue-authenticate-auth0-1.3.8.tgz: package/src/oauth/oauth2.js <==
import OAuthPopup from './popup.js'
import { camelCase, isFunction, isString, objectExtend, joinUrl } from '../utils.js'

/**
 * Default provider configuration
 * @type {Object}
 */
const defaultProviderConfig = {
  name: null,
  url: null,
  client_id: null,
  authorizationEndpoint: null,
  redirect_uri: null,
  scope: null,
  scopePrefix: null,
  scopeDelimiter: null,
  state: null,
  requiredUrlParams: null,
  defaultUrlParams: ['response_type', 'client_id', 'redirect_uri'],
  responseType: 'code',
  responseParams: {
    code: 'code',
    client_id: 'client_id',
    redirect_uri: 'redirect_uri',
    grant_type: 'grant_type'
  },
  oauthType: '2.0',
  popupOptions: {}
}

export default class OAuth2 {
  constructor($http, storage, providerConfig, options) {
    this.$http = $http
    this.storage = storage
    this.providerConfig = objectExtend({}, defaultProviderConfig)
    this.providerConfig = objectExtend(this.providerConfig, providerConfig)
    this.options = options
  }

  init(userData) {
    let stateName = this.providerConfig.name + '_state';
    if (isFunction(this.providerConfig.state)) {
      this.storage.setItem(stateName, this.providerConfig.state())
    } else if (isString(this.providerConfig.state)) {
      this.storage.setItem(stateName, this.providerConfig.state)
    }

    let url = [this.providerConfig.authorizationEndpoint, this._stringifyRequestParams()].join('?')

    this.oauthPopup = new OAuthPopup(url, this.providerConfig.name, this.providerConfig.popupOptions)
    
    return new Promise((resolve, reject) => {
      this.oauthPopup.open(this.providerConfig.redirectUri).then((response) => {
        if (this.providerConfig.responseType === 'token' || !this.providerConfig.url) {
          return resolve(response)
        }

        if (response.state && response.state !== this.storage.getItem(stateName)) {
          return reject(new Error('State parameter value does not match original OAuth request state value'))
        }

        resolve(this.exchangeForToken(response, userData))
      }).catch((err) => {
        reject(err)
      })
    })
  }

  /**
   * Exchange temporary oauth data for access token
   * @author Sahat Yalkabov <https://github.com/sahat>
   * @copyright Method taken from https://github.com/sahat/satellizer
   * 
   * @param  {[type]} oauth    [description]
   * @param  {[type]} userData [description]
   * @return {[type]}          [description]
   */
  exchangeForToken(oauth, userData) {
    let payload = objectExtend({}, userData)

    for (let key in defaultProviderConfig.responseParams) {
      let value = defaultProviderConfig.responseParams[key]

      switch(key) {
        case 'grant_type':
            payload[value] = 'authorization_code'
            break
        case 'code':
            payload[value] = oauth.code
            break
        case 'client_id':
          payload[value] = this.providerConfig.clientId
          break
        case 'redirect_uri':
          payload[value] = this.providerConfig.redirectUri
          break
        default:
          payload[value] = oauth[key]
      }
    }

    if (oauth.state) {
      payload.state = oauth.state
    }

    let exchangeTokenUrl
    if (this.options.baseUrl) {
      exchangeTokenUrl = joinUrl(this.options.baseUrl, this.providerConfig.url)
    } else {
      exchangeTokenUrl = this.providerConfig.url
    }

    return this.$http.post(exchangeTokenUrl, payload, {
      withCredentials: this.options.withCredentials
    })
  }

  /**
   * Stringify oauth params
   * @author Sahat Yalkabov <https://github.com/sahat>
   * @copyright Method taken from https://github.com/sahat/satellizer
   * 
   * @return {String}
   */
  _stringifyRequestParams() {
    let keyValuePairs = []
    let paramCategories = ['defaultUrlParams', 'requiredUrlParams', 'optionalUrlParams']

    paramCategories.forEach((categoryName) => {
      if (!this.providerConfig[categoryName]) return
      if (!Array.isArray(this.providerConfig[categoryName])) return

      this.providerConfig[categoryName].forEach((paramName) => {
        let camelCaseParamName = camelCase(paramName)
        let paramValue = isFunction(this.providerConfig[paramName]) ? this.providerConfig[paramName]() : this.providerConfig[camelCaseParamName]

        if (paramName === 'redirect_uri' && !paramValue) return

        if (paramName === 'state') {
          let stateName = this.providerConfig.name + '_state';
          paramValue = encodeURIComponent(this.storage.getItem(stateName));
        }
        if (paramName === 'scope' && Array.isArray(paramValue)) {
          paramValue = paramValue.join(this.providerConfig.scopeDelimiter);
          if (this.providerConfig.scopePrefix) {
            paramValue = [this.providerConfig.scopePrefix, paramValue].join(this.providerConfig.scopeDelimiter);
          }
        }

        keyValuePairs.push([paramName, paramValue])
      })
    })

    return keyValuePairs.map((param) => {
      return param.join('=')
    }).join('&')
  }
}

==> vue-authenticate-auth0-1.3.9.tgz: package/src/oauth/oauth2.js <==
import OAuthPopup from './popup.js'
import { camelCase, isFunction, isString, objectExtend, joinUrl } from '../utils.js'

/**
 * Default provider configuration
 * @type {Object}
 */
const defaultProviderConfig = {
  name: null,
  url: null,
  client_id: null,
  authorizationEndpoint: null,
  redirect_uri: null,
  scope: null,
  scopePrefix: null,
  scopeDelimiter: null,
  state: null,
  requiredUrlParams: null,
  defaultUrlParams: ['response_type', 'client_id', 'redirect_uri'],
  responseType: 'code',
  responseParams: {
    code: 'code',
    client_id: 'client_id',
    redirect_uri: 'redirect_uri',
    grant_type: 'grant_type'
  },
  oauthType: '2.0',
  popupOptions: {}
}

export default class OAuth2 {
  constructor($http, storage, providerConfig, options) {
    this.$http = $http
    this.storage = storage
    this.providerConfig = objectExtend({}, defaultProviderConfig)
    this.providerConfig = objectExtend(this.providerConfig, providerConfig)
    this.options = options
  }

  init(userData) {
    let stateName = this.providerConfig.name + '_state';
    if (isFunction(this.providerConfig.state)) {
      this.storage.setItem(stateName, this.providerConfig.state())
    } else if (isString(this.providerConfig.state)) {
      this.storage.setItem(stateName, this.providerConfig.state)
    }

    let url = [this.providerConfig.authorizationEndpoint, this._stringifyRequestParams()].join('?')

    this.oauthPopup = new OAuthPopup(url, this.providerConfig.name, this.providerConfig.popupOptions)
    
    return new Promise((resolve, reject) => {
      this.oauthPopup.open(this.providerConfig.redirect_uri).then((response) => {
        if (this.providerConfig.responseType === 'token' || !this.providerConfig.url) {
          return resolve(response)
        }

        if (response.state && response.state !== this.storage.getItem(stateName)) {
          return reject(new Error('State parameter value does not match original OAuth request state value'))
        }

        resolve(this.exchangeForToken(response, userData))
      }).catch((err) => {
        reject(err)
      })
    })
  }

  /**
   * Exchange temporary oauth data for access token
   * @author Sahat Yalkabov <https://github.com/sahat>
   * @copyright Method taken from https://github.com/sahat/satellizer
   * 
   * @param  {[type]} oauth    [description]
   * @param  {[type]} userData [description]
   * @return {[type]}          [description]
   */
  exchangeForToken(oauth, userData) {
    let payload = objectExtend({}, userData)

    for (let key in defaultProviderConfig.responseParams) {
      let value = defaultProviderConfig.responseParams[key]

      switch(key) {
        case 'grant_type':
            payload[value] = 'authorization_code'
            break
        case 'code':
            payload[value] = oauth.code
            break
        case 'client_id':
          payload[value] = this.providerConfig.client_id
          break
        case 'redirect_uri':
          payload[value] = this.providerConfig.redirect_uri
          break
        default:
          payload[value] = oauth[key]
      }
    }

    if (oauth.state) {
      payload.state = oauth.state
    }

    let exchangeTokenUrl
    if (this.options.baseUrl) {
      exchangeTokenUrl = joinUrl(this.options.baseUrl, this.providerConfig.url)
    } else {
      exchangeTokenUrl = this.providerConfig.url
    }

    return this.$http.post(exchangeTokenUrl, payload, {
      withCredentials: this.options.withCredentials
    })
  }

  /**
   * Stringify oauth params
   * @author Sahat Yalkabov <https://github.com/sahat>
   * @copyright Method taken from https://github.com/sahat/satellizer
   * 
   * @return {String}
   */
  _stringifyRequestParams() {
    let keyValuePairs = []
    let paramCategories = ['defaultUrlParams', 'requiredUrlParams', 'optionalUrlParams']

    paramCategories.forEach((categoryName) => {
      if (!this.providerConfig[categoryName]) return
      if (!Array.isArray(this.providerConfig[categoryName])) return

      this.providerConfig[categoryName].forEach((paramName) => {
        let camelCaseParamName = camelCase(paramName)
        let paramValue = isFunction(this.providerConfig[paramName]) ? this.providerConfig[paramName]() : this.providerConfig[camelCaseParamName]

        if (paramName === 'redirect_uri' && !paramValue) return

        if (paramName === 'state') {
          let stateName = this.providerConfig.name + '_state';
          paramValue = encodeURIComponent(this.storage.getItem(stateName));
        }
        if (paramName === 'scope' && Array.isArray(paramValue)) {
          paramValue = paramValue.join(this.providerConfig.scopeDelimiter);
          if (this.providerConfig.scopePrefix) {
            paramValue = [this.providerConfig.scopePrefix, paramValue].join(this.providerConfig.scopeDelimiter);
          }
        }

        keyValuePairs.push([paramName, paramValue])
      })
    })

    return keyValuePairs.map((param) => {
      return param.join('=')
    }).join('&')
  }
}
